'use client';

import Link from 'next/link';
import {
  BasedAvatar,
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from '@/components/ui';
import { useAuth, useTVMode } from '@/components/context';
import { useRouter } from 'next/navigation';
import { signOut } from '@/lib/actions';

const AvatarDropdown = () => {
  const { profile, refreshUserData } = useAuth();
  const router = useRouter();
  const { toggleTVMode, tvMode } = useTVMode();

  const handleSignOut = async () => {
    const result = await signOut();
    if (result?.success) {
      await refreshUserData();
      router.push('/sign-in');
    }
  };

  return (
    <DropdownMenu>
      <DropdownMenuTrigger>
        <BasedAvatar
          src={profile?.avatar_url}
          fullName={profile?.full_name}
          className='h-12 w-12 my-auto'
          fallbackClassName='text-xl font-semibold'
          userIconSize={32}
        />
      </DropdownMenuTrigger>
      <DropdownMenuContent>
        <DropdownMenuLabel className='font-bold'>
          {profile?.full_name}
        </DropdownMenuLabel>
        <DropdownMenuSeparator />
        <DropdownMenuItem asChild>
          <button
            onClick={toggleTVMode}
            className='w-full justify-center cursor-pointer'
          >
            {tvMode ? 'Normal Mode' : 'TV Mode'}
          </button>
        </DropdownMenuItem>
        <DropdownMenuSeparator className='h-[2px]' />
        <DropdownMenuItem asChild>
          <Link
            href='/profile'
            className='w-full justify-center cursor-pointer'
          >
            Edit profile
          </Link>
        </DropdownMenuItem>
        <DropdownMenuSeparator className='h-[2px]' />
        <DropdownMenuItem asChild>
          <button
            onClick={handleSignOut}
            className='w-full justify-center cursor-pointer'
          >
            Sign Out
          </button>
        </DropdownMenuItem>
      </DropdownMenuContent>
    </DropdownMenu>
  );
};
export default AvatarDropdown;
